"""Auto-generated file, do not edit by hand. 27 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_27 = [NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['86[1-9]'])]
